@@ -263,23 +263,31 @@ class BaseType:
         )
 
     def __or__(self, other):
-        from .infix import _ewise_infix_expr
+        from .infix import _ewise_infix_expr, _ewise_mult_expr_types
 
+        if isinstance(other, _ewise_mult_expr_types):
+            raise TypeError("XXX")
         return _ewise_infix_expr(self, other, method="ewise_add", within="__or__")
 
     def __ror__(self, other):
-        from .infix import _ewise_infix_expr
+        from .infix import _ewise_infix_expr, _ewise_mult_expr_types
 
+        if isinstance(other, _ewise_mult_expr_types):
+            raise TypeError("XXX")
         return _ewise_infix_expr(other, self, method="ewise_add", within="__ror__")
 
     def __and__(self, other):
-        from .infix import _ewise_infix_expr
+        from .infix import _ewise_add_expr_types, _ewise_infix_expr
 
+        if isinstance(other, _ewise_add_expr_types):
+            raise TypeError("XXX")
         return _ewise_infix_expr(self, other, method="ewise_mult", within="__and__")
 
     def __rand__(self, other):
-        from .infix import _ewise_infix_expr
+        from .infix import _ewise_add_expr_types, _ewise_infix_expr
 
+        if isinstance(other, _ewise_add_expr_types):
+            raise TypeError("XXX")
         return _ewise_infix_expr(other, self, method="ewise_mult", within="__rand__")
 
     def __matmul__(self, other):
