@@ -1,16 +1,16 @@
 import itertools
 
 import numpy as np
-from numba import njit
 from suitesparse_graphblas.utils import claim_buffer, unclaim_buffer
 
 import graphblas as gb
 
 from ... import binary, monoid
-from ...dtypes import _INDEX, INT64, UINT64, _string_to_dtype, lookup_dtype
+from ...dtypes import _INDEX, INT64, UINT64, lookup_dtype
 from ...exceptions import _error_code_lookup, check_status, check_status_carg
 from .. import NULL, ffi, lib
 from ..base import call
+from ..dtypes import _string_to_dtype
 from ..operator import get_typed_op
 from ..scalar import Scalar, _as_scalar
 from ..utils import (
@@ -23,7 +23,7 @@ from ..utils import (
 )
 from .config import BaseConfig
 from .descriptor import get_descriptor
-from .matrix import _concat_mn
+from .matrix import _concat_mn, njit
 from .prefix_scan import prefix_scan
 
 ffi_new = ffi.new
@@ -145,8 +145,7 @@ class ss:
         return format
 
     def build_diag(self, matrix, k=0, **opts):
-        """
-        GxB_Vector_diag.
+        """GxB_Vector_diag.
 
         Extract a diagonal from a Matrix or TransposedMatrix into a Vector.
         Existing entries in the Vector are discarded.
@@ -156,8 +155,8 @@ class ss:
         matrix : Matrix or TransposedMatrix
             Extract a diagonal from this matrix.
         k : int, default 0
-            Diagonal in question.  Use `k>0` for diagonals above the main diagonal,
-            and `k<0` for diagonals below the main diagonal.
+            Diagonal in question.  Use ``k>0`` for diagonals above the main diagonal,
+            and ``k<0`` for diagonals below the main diagonal.
 
         See Also
         --------
@@ -183,15 +182,14 @@ class ss:
         )
 
     def split(self, chunks, *, name=None, **opts):
-        """
-        GxB_Matrix_split.
+        """GxB_Matrix_split.
 
-        Split a Vector into a 1D array of sub-vectors according to `chunks`.
+        Split a Vector into a 1D array of sub-vectors according to ``chunks``.
 
         This performs the opposite operation as ``concat``.
 
-        `chunks` is short for "chunksizes" and indicates the chunk sizes.
-        `chunks` may be a single integer, or a tuple or list.  Example chunks:
+        ``chunks`` is short for "chunksizes" and indicates the chunk sizes.
+        ``chunks`` may be a single integer, or a tuple or list.  Example chunks:
 
         - ``chunks=10``
             - Split vector into chunks of size 10 (the last chunk may be smaller).
@@ -202,6 +200,7 @@ class ss:
         --------
         Vector.ss.concat
         graphblas.ss.concat
+
         """
         from ..vector import Vector
 
@@ -249,12 +248,11 @@ class ss:
         )
 
     def concat(self, tiles, **opts):
-        """
-        GxB_Matrix_concat.
+        """GxB_Matrix_concat.
 
         Concatenate a 1D list of Vector objects into the current Vector.
         Any existing values in the current Vector will be discarded.
-        To concatenate into a new Vector, use `graphblas.ss.concat`.
+        To concatenate into a new Vector, use ``graphblas.ss.concat``.
 
         This performs the opposite operation as ``split``.
 
@@ -262,13 +260,13 @@ class ss:
         --------
         Vector.ss.split
         graphblas.ss.concat
+
         """
         tiles, m, n, is_matrix = _concat_mn(tiles, is_matrix=False)
         self._concat(tiles, m, opts)
 
     def build_scalar(self, indices, value):
-        """
-        GxB_Vector_build_Scalar.
+        """GxB_Vector_build_Scalar.
 
         Like ``build``, but uses a scalar for all the values.
 
@@ -276,6 +274,7 @@ class ss:
         --------
         Vector.build
         Vector.from_coo
+
         """
         indices = ints_to_numpy_buffer(indices, np.uint64, name="indices")
         scalar = _as_scalar(value, self._parent.dtype, is_cscalar=False)  # pragma: is_grbscalar
@@ -410,14 +409,13 @@ class ss:
             lib.GxB_Iterator_free(it_ptr)
 
     def export(self, format=None, *, sort=False, give_ownership=False, raw=False, **opts):
-        """
-        GxB_Vextor_export_xxx.
+        """GxB_Vextor_export_xxx.
 
         Parameters
         ----------
         format : str or None, default None
-            If `format` is not specified, this method exports in the currently stored format.
-            To control the export format, set `format` to one of:
+            If ``format`` is not specified, this method exports in the currently stored format.
+            To control the export format, set ``format`` to one of:
                 - "sparse"
                 - "bitmap"
                 - "full"
@@ -435,7 +433,7 @@ class ss:
 
         Returns
         -------
-        dict; keys depend on `format` and `raw` arguments (see below).
+        dict; keys depend on ``format`` and ``raw`` arguments (see below).
 
         See Also
         --------
@@ -443,7 +441,7 @@ class ss:
         Vector.ss.import_any
 
         Return values
-            - Note: for `raw=True`, arrays may be larger than specified.
+            - Note: for ``raw=True``, arrays may be larger than specified.
             - "sparse" format
                 - indices : ndarray(dtype=uint64, size=nvals)
                 - values : ndarray(size=nvals)
@@ -468,6 +466,7 @@ class ss:
 
         >>> pieces = v.ss.export()
         >>> v2 = Vector.ss.import_any(**pieces)
+
         """
         return self._export(
             format=format,
@@ -479,13 +478,12 @@ class ss:
         )
 
     def unpack(self, format=None, *, sort=False, raw=False, **opts):
-        """
-        GxB_Vector_unpack_xxx.
+        """GxB_Vector_unpack_xxx.
 
-        `unpack` is like `export`, except that the Vector remains valid but empty.
-        `pack_*` methods are the opposite of `unpack`.
+        ``unpack`` is like ``export``, except that the Vector remains valid but empty.
+        ``pack_*`` methods are the opposite of ``unpack``.
 
-        See `Vector.ss.export` documentation for more details.
+        See ``Vector.ss.export`` documentation for more details.
         """
         return self._export(
             format=format, sort=sort, give_ownership=True, raw=raw, method="unpack", opts=opts
@@ -588,7 +586,7 @@ class ss:
                 if is_iso:
                     if values.size > 1:  # pragma: no cover (suitesparse)
                         values = values[:1]
-                elif values.size > size:  # pragma: no branch (suitesparse)
+                elif values.size > size:  # pragma: no cover (suitesparse)
                     values = values[:size]
             rv = {
                 "bitmap": bitmap,
@@ -655,11 +653,10 @@ class ss:
         nvals=None,  # optional
         **opts,
     ):
-        """
-        GxB_Vector_import_xxx.
+        """GxB_Vector_import_xxx.
 
         Dispatch to appropriate import method inferred from inputs.
-        See the other import functions and `Vector.ss.export`` for details.
+        See the other import functions and ``Vector.ss.export`` for details.
 
         Returns
         -------
@@ -679,6 +676,7 @@ class ss:
 
         >>> pieces = v.ss.export()
         >>> v2 = Vector.ss.import_any(**pieces)
+
         """
         return cls._import_any(
             values=values,
@@ -722,13 +720,12 @@ class ss:
         name=None,
         **opts,
     ):
-        """
-        GxB_Vector_pack_xxx.
+        """GxB_Vector_pack_xxx.
 
-        `pack_any` is like `import_any` except it "packs" data into an
+        ``pack_any`` is like ``import_any`` except it "packs" data into an
         existing Vector.  This is the opposite of ``unpack()``
 
-        See `Vector.ss.import_any` documentation for more details.
+        See ``Vector.ss.import_any`` documentation for more details.
         """
         return self._import_any(
             values=values,
@@ -844,8 +841,7 @@ class ss:
         name=None,
         **opts,
     ):
-        """
-        GxB_Vector_import_CSC.
+        """GxB_Vector_import_CSC.
 
         Create a new Vector from sparse input.
 
@@ -859,7 +855,7 @@ class ss:
             If not specified, will be set to ``len(values)``.
         is_iso : bool, default False
             Is the Vector iso-valued (meaning all the same value)?
-            If true, then `values` should be a length 1 array.
+            If true, then ``values`` should be a length 1 array.
         sorted_index : bool, default False
             Indicate whether the values in "col_indices" are sorted.
         take_ownership : bool, default False
@@ -876,7 +872,7 @@ class ss:
             read-only and will no longer own the data.
         dtype : dtype, optional
             dtype of the new Vector.
-            If not specified, this will be inferred from `values`.
+            If not specified, this will be inferred from ``values``.
         format : str, optional
             Must be "sparse" or None.  This is included to be compatible with
             the dict returned from exporting.
@@ -886,6 +882,7 @@ class ss:
         Returns
         -------
         Vector
+
         """
         return cls._import_sparse(
             size=size,
@@ -920,13 +917,12 @@ class ss:
         name=None,
         **opts,
     ):
-        """
-        GxB_Vector_pack_CSC.
+        """GxB_Vector_pack_CSC.
 
-        `pack_sparse` is like `import_sparse` except it "packs" data into an
+        ``pack_sparse`` is like ``import_sparse`` except it "packs" data into an
         existing Vector.  This is the opposite of ``unpack("sparse")``
 
-        See `Vector.ss.import_sparse` documentation for more details.
+        See ``Vector.ss.import_sparse`` documentation for more details.
         """
         return self._import_sparse(
             indices=indices,
@@ -1029,8 +1025,7 @@ class ss:
         name=None,
         **opts,
     ):
-        """
-        GxB_Vector_import_Bitmap.
+        """GxB_Vector_import_Bitmap.
 
         Create a new Vector from values and bitmap (as mask) arrays.
 
@@ -1046,7 +1041,7 @@ class ss:
             If not specified, it will be set to the size of values.
         is_iso : bool, default False
             Is the Vector iso-valued (meaning all the same value)?
-            If true, then `values` should be a length 1 array.
+            If true, then ``values`` should be a length 1 array.
         take_ownership : bool, default False
             If True, perform a zero-copy data transfer from input numpy arrays
             to GraphBLAS if possible.  To give ownership of the underlying
@@ -1061,7 +1056,7 @@ class ss:
             read-only and will no longer own the data.
         dtype : dtype, optional
             dtype of the new Vector.
-            If not specified, this will be inferred from `values`.
+            If not specified, this will be inferred from ``values``.
         format : str, optional
             Must be "bitmap" or None.  This is included to be compatible with
             the dict returned from exporting.
@@ -1071,6 +1066,7 @@ class ss:
         Returns
         -------
         Vector
+
         """
         return cls._import_bitmap(
             bitmap=bitmap,
@@ -1103,13 +1099,12 @@ class ss:
         name=None,
         **opts,
     ):
-        """
-        GxB_Vector_pack_Bitmap.
+        """GxB_Vector_pack_Bitmap.
 
-        `pack_bitmap` is like `import_bitmap` except it "packs" data into an
+        ``pack_bitmap`` is like ``import_bitmap`` except it "packs" data into an
         existing Vector.  This is the opposite of ``unpack("bitmap")``
 
-        See `Vector.ss.import_bitmap` documentation for more details.
+        See ``Vector.ss.import_bitmap`` documentation for more details.
         """
         return self._import_bitmap(
             bitmap=bitmap,
@@ -1214,8 +1209,7 @@ class ss:
         name=None,
         **opts,
     ):
-        """
-        GxB_Vector_import_Full.
+        """GxB_Vector_import_Full.
 
         Create a new Vector from values.
 
@@ -1227,7 +1221,7 @@ class ss:
             If not specified, it will be set to the size of values.
         is_iso : bool, default False
             Is the Vector iso-valued (meaning all the same value)?
-            If true, then `values` should be a length 1 array.
+            If true, then ``values`` should be a length 1 array.
         take_ownership : bool, default False
             If True, perform a zero-copy data transfer from input numpy arrays
             to GraphBLAS if possible.  To give ownership of the underlying
@@ -1242,7 +1236,7 @@ class ss:
             read-only and will no longer own the data.
         dtype : dtype, optional
             dtype of the new Vector.
-            If not specified, this will be inferred from `values`.
+            If not specified, this will be inferred from ``values``.
         format : str, optional
             Must be "full" or None.  This is included to be compatible with
             the dict returned from exporting.
@@ -1252,6 +1246,7 @@ class ss:
         Returns
         -------
         Vector
+
         """
         return cls._import_full(
             values=values,
@@ -1280,13 +1275,12 @@ class ss:
         name=None,
         **opts,
     ):
-        """
-        GxB_Vector_pack_Full.
+        """GxB_Vector_pack_Full.
 
-        `pack_full` is like `import_full` except it "packs" data into an
+        ``pack_full`` is like ``import_full`` except it "packs" data into an
         existing Vector.  This is the opposite of ``unpack("full")``
 
-        See `Vector.ss.import_full` documentation for more details.
+        See ``Vector.ss.import_full`` documentation for more details.
         """
         return self._import_full(
             values=values,
@@ -1365,12 +1359,13 @@ class ss:
     def scan(self, op=monoid.plus, *, name=None, **opts):
         """Perform a prefix scan with the given monoid.
 
-        For example, use `monoid.plus` (the default) to perform a cumulative sum,
-        and `monoid.times` for cumulative product.  Works with any monoid.
+        For example, use ``monoid.plus`` (the default) to perform a cumulative sum,
+        and ``monoid.times`` for cumulative product.  Works with any monoid.
 
         Returns
         -------
         Scalar
+
         """
         return prefix_scan(self._parent, op, name=name, within="scan", **opts)
 
@@ -1401,6 +1396,7 @@ class ss:
         See Also
         --------
         Matrix.ss.flatten : flatten a Matrix into a Vector.
+
         """
         return self._parent._as_matrix().ss.reshape(nrows, ncols, order, name=name, **opts)
 
@@ -1420,6 +1416,7 @@ class ss:
             The number of elements to choose
 
         **THIS API IS EXPERIMENTAL AND MAY CHANGE**
+
         """
         how = how.lower()
         if k < 0:
@@ -1562,20 +1559,20 @@ class ss:
     def sort(self, op=binary.lt, *, values=True, permutation=True, **opts):
         """GxB_Vector_sort to sort values of the Vector.
 
-        Sorting moves all the elements to the left just like `compactify`.
+        Sorting moves all the elements to the left just like ``compactify``.
         The returned vectors will be the same size as the input Vector.
 
         Parameters
         ----------
         op : :class:`~graphblas.core.operator.BinaryOp`, optional
             Binary operator with a bool return type used to sort the values.
-            For example, `binary.lt` (the default) sorts the smallest elements first.
+            For example, ``binary.lt`` (the default) sorts the smallest elements first.
             Ties are broken according to indices (smaller first).
         values : bool, default=True
-            Whether to return values; will return `None` for values if `False`.
+            Whether to return values; will return ``None`` for values if ``False``.
         permutation : bool, default=True
             Whether to compute the permutation Vector that has the original indices of the
-            sorted values. Will return None if `False`.
+            sorted values. Will return None if ``False``.
         nthreads : int, optional
             The maximum number of threads to use for this operation.
             None, 0 or negative nthreads means to use the default number of threads.
@@ -1588,6 +1585,7 @@ class ss:
         See Also
         --------
         Vector.ss.compactify
+
         """
         from ..vector import Vector
 
@@ -1643,11 +1641,12 @@ class ss:
             None, 0 or negative nthreads means to use the default number of threads.
 
         For best performance, this function returns a numpy array with uint8 dtype.
-        Use `Vector.ss.deserialize(blob)` to create a Vector from the result of serialization·
+        Use ``Vector.ss.deserialize(blob)`` to create a Vector from the result of serialization·
 
         This method is intended to support all serialization options from SuiteSparse:GraphBLAS.
 
         *Warning*: Behavior of serializing UDTs is experimental and may change in a future release.
+
         """
         desc = get_descriptor(compression=compression, compression_level=level, **opts)
         blob_handle = ffi_new("void**")
@@ -1669,7 +1668,7 @@ class ss:
         """Deserialize a Vector from bytes, buffer, or numpy array using GxB_Vector_deserialize.
 
         The data should have been previously serialized with a compatible version of
-        SuiteSparse:GraphBLAS.  For example, from the result of `data = vector.ss.serialize()`.
+        SuiteSparse:GraphBLAS.  For example, from the result of ``data = vector.ss.serialize()``.
 
         Examples
         --------
@@ -1687,6 +1686,7 @@ class ss:
         nthreads : int, optional
             The maximum number of threads to use when deserializing.
             None, 0 or negative nthreads means to use the default number of threads.
+
         """
         if isinstance(data, np.ndarray):
             data = ints_to_numpy_buffer(data, np.uint8)
