@@ -1,17 +1,23 @@
 import itertools
-import warnings
 
 import numpy as np
 
-from .. import backend, binary, monoid, select, semiring
+from .. import backend, binary, monoid, select, semiring, unary
 from ..dtypes import _INDEX, FP64, INT64, lookup_dtype, unify
 from ..exceptions import DimensionMismatch, NoValue, check_status
-from . import automethods, ffi, lib, utils
+from . import _supports_udfs, automethods, ffi, lib, utils
 from .base import BaseExpression, BaseType, _check_mask, call
 from .descriptor import lookup as descriptor_lookup
-from .expr import _ALL_INDICES, AmbiguousAssignOrExtract, IndexerResolver, Updater
+from .expr import _ALL_INDICES, AmbiguousAssignOrExtract, IndexerResolver, InfixExprBase, Updater
 from .mask import Mask, StructuralMask, ValueMask
-from .operator import UNKNOWN_OPCLASS, find_opclass, get_semiring, get_typed_op, op_from_string
+from .operator import (
+    UNKNOWN_OPCLASS,
+    _get_typed_op_from_exprs,
+    find_opclass,
+    get_semiring,
+    get_typed_op,
+    op_from_string,
+)
 from .scalar import (
     _COMPLETE,
     _MATERIALIZE,
@@ -61,13 +67,13 @@ def _v_union_m(updater, left, right, left_default, right_default, op):
     updater << temp.ewise_union(right, op, left_default=left_default, right_default=right_default)
 
 
-def _v_union_v(updater, left, right, left_default, right_default, op, dtype):
+def _v_union_v(updater, left, right, left_default, right_default, op):
     mask = updater.kwargs.get("mask")
     opts = updater.opts
-    new_left = left.dup(dtype, clear=True)
+    new_left = left.dup(op.type, clear=True)
     new_left(mask=mask, **opts) << binary.second(right, left_default)
     new_left(mask=mask, **opts) << binary.first(left | new_left)
-    new_right = right.dup(dtype, clear=True)
+    new_right = right.dup(op.type2, clear=True)
     new_right(mask=mask, **opts) << binary.second(left, right_default)
     new_right(mask=mask, **opts) << binary.first(right | new_right)
     updater << op(new_left & new_right)
@@ -93,6 +99,45 @@ def _select_mask(updater, obj, mask):
         updater << obj.dup(mask=mask)
 
 
+def _isclose_recipe(self, other, rel_tol, abs_tol, **opts):
+    #  x == y or abs(x - y) <= max(rel_tol * max(abs(x), abs(y)), abs_tol)
+    isequal = self.ewise_mult(other, binary.eq).new(bool, name="isclose", **opts)
+    if isequal._nvals != self._nvals:
+        return False
+    if type(isequal) is Vector:
+        val = isequal.reduce(monoid.land, allow_empty=False).new(**opts).value
+    else:
+        val = isequal.reduce_scalar(monoid.land, allow_empty=False).new(**opts).value
+    if val:
+        return True
+    # So we can use structural mask below
+    isequal(**opts) << select.value(isequal == True)  # noqa: E712
+
+    # abs(x)
+    x = self.apply(unary.abs).new(FP64, mask=~isequal.S, **opts)
+    # abs(y)
+    y = other.apply(unary.abs).new(FP64, mask=~isequal.S, **opts)
+    # max(abs(x), abs(y))
+    x(**opts) << x.ewise_mult(y, binary.max)
+    max_x_y = x
+    # rel_tol * max(abs(x), abs(y))
+    max_x_y(**opts) << max_x_y.apply(binary.times, rel_tol)
+    # max(rel_tol * max(abs(x), abs(y)), abs_tol)
+    max_x_y(**opts) << max_x_y.apply(binary.max, abs_tol)
+
+    # x - y
+    y(~isequal.S, replace=True, **opts) << self.ewise_mult(other, binary.minus)
+    abs_x_y = y
+    # abs(x - y)
+    abs_x_y(**opts) << abs_x_y.apply(unary.abs)
+
+    # abs(x - y) <= max(rel_tol * max(abs(x), abs(y)), abs_tol)
+    isequal(**opts) << abs_x_y.ewise_mult(max_x_y, binary.le)
+    if isequal.ndim == 1:
+        return isequal.reduce(monoid.land, allow_empty=False).new(**opts).value
+    return isequal.reduce_scalar(monoid.land, allow_empty=False).new(**opts).value
+
+
 class Vector(BaseType):
     """Create a new GraphBLAS Sparse Vector.
 
@@ -104,6 +149,7 @@ class Vector(BaseType):
         Size of the Vector.
     name : str, optional
         Name to give the Vector. This will be displayed in the ``__repr__``.
+
     """
 
     __slots__ = "_size", "_parent", "ss"
@@ -220,6 +266,7 @@ class Vector(BaseType):
         Examples
         --------
             >>> del v[1:-1]
+
         """
         del Updater(self, opts=opts)[keys]
 
@@ -234,6 +281,7 @@ class Vector(BaseType):
         .. code-block:: python
 
             sub_v = v[[1, 3, 5]].new()
+
         """
         resolved_indexes = IndexerResolver(self, keys)
         shape = resolved_indexes.shape
@@ -253,6 +301,7 @@ class Vector(BaseType):
 
             # This makes a dense iso-value vector
             v[:] = 1
+
         """
         Updater(self, opts=opts)[keys] = expr
 
@@ -265,6 +314,7 @@ class Vector(BaseType):
 
             # Check if v[15] is non-empty
             15 in v
+
         """
         extractor = self[index]
         if not extractor._is_scalar:
@@ -304,6 +354,7 @@ class Vector(BaseType):
         See Also
         --------
         :meth:`isclose` : For equality check of floating point dtypes
+
         """
         other = self._expect_type(other, Vector, within="isequal", argname="other")
         if check_dtype and self.dtype != other.dtype:
@@ -346,6 +397,7 @@ class Vector(BaseType):
         Returns
         -------
         bool
+
         """
         other = self._expect_type(other, Vector, within="isclose", argname="other")
         if check_dtype and self.dtype != other.dtype:
@@ -354,6 +406,8 @@ class Vector(BaseType):
             return False
         if self._nvals != other._nvals:
             return False
+        if not _supports_udfs:
+            return _isclose_recipe(self, other, rel_tol, abs_tol, **opts)
 
         matches = self.ewise_mult(other, binary.isclose(rel_tol, abs_tol)).new(
             bool, name="M_isclose", **opts
@@ -408,36 +462,6 @@ class Vector(BaseType):
         call("GrB_Vector_resize", [self, size])
         self._size = size.value
 
-    def to_values(self, dtype=None, *, indices=True, values=True, sort=True):
-        """Extract the indices and values as a 2-tuple of numpy arrays.
-
-        .. deprecated:: 2022.11.0
-            `Vector.to_values` will be removed in a future release.
-            Use `Vector.to_coo` instead. Will be removed in version 2023.9.0 or later
-
-        Parameters
-        ----------
-        dtype :
-            Requested dtype for the output values array.
-        indices :bool, default=True
-            Whether to return indices; will return `None` for indices if `False`
-        values : bool, default=True
-            Whether to return values; will return `None` for values if `False`
-        sort : bool, default=True
-            Whether to require sorted indices.
-
-        Returns
-        -------
-        np.ndarray[dtype=uint64] : Indices
-        np.ndarray : Values
-        """
-        warnings.warn(
-            "`Vector.to_values(...)` is deprecated; please use `Vector.to_coo(...)` instead.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.to_coo(dtype, indices=indices, values=values, sort=sort)
-
     def to_coo(self, dtype=None, *, indices=True, values=True, sort=True):
         """Extract the indices and values as a 2-tuple of numpy arrays.
 
@@ -446,9 +470,9 @@ class Vector(BaseType):
         dtype :
             Requested dtype for the output values array.
         indices :bool, default=True
-            Whether to return indices; will return `None` for indices if `False`
+            Whether to return indices; will return ``None`` for indices if ``False``
         values : bool, default=True
-            Whether to return values; will return `None` for values if `False`
+            Whether to return values; will return ``None`` for values if ``False``
         sort : bool, default=True
             Whether to require sorted indices.
 
@@ -462,6 +486,7 @@ class Vector(BaseType):
         -------
         np.ndarray[dtype=uint64] : Indices
         np.ndarray : Values
+
         """
         if sort and backend == "suitesparse":
             self.wait()  # sort in SS
@@ -498,7 +523,7 @@ class Vector(BaseType):
         """Rarely used method to insert values into an existing Vector. The typical use case
         is to create a new Vector and insert values at the same time using :meth:`from_coo`.
 
-        All the arguments are used identically in :meth:`from_coo`, except for `clear`, which
+        All the arguments are used identically in :meth:`from_coo`, except for ``clear``, which
         indicates whether to clear the Vector prior to adding the new values.
         """
         # TODO: accept `dtype` keyword to match the dtype of `values`?
@@ -520,14 +545,15 @@ class Vector(BaseType):
         if not dup_op_given:
             if not self.dtype._is_udt:
                 dup_op = binary.plus
-            else:
+            elif backend != "suitesparse":
                 dup_op = binary.any
-        # SS:SuiteSparse-specific: we could use NULL for dup_op
-        dup_op = get_typed_op(dup_op, self.dtype, kind="binary")
-        if dup_op.opclass == "Monoid":
-            dup_op = dup_op.binaryop
-        else:
-            self._expect_op(dup_op, "BinaryOp", within="build", argname="dup_op")
+            # SS:SuiteSparse-specific: we use NULL for dup_op
+        if dup_op is not None:
+            dup_op = get_typed_op(dup_op, self.dtype, kind="binary")
+            if dup_op.opclass == "Monoid":
+                dup_op = dup_op.binaryop
+            else:
+                self._expect_op(dup_op, "BinaryOp", within="build", argname="dup_op")
 
         indices = _CArray(indices)
         values = _CArray(values, self.dtype)
@@ -560,6 +586,7 @@ class Vector(BaseType):
         Returns
         -------
         Vector
+
         """
         if dtype is not None or mask is not None or clear:
             if dtype is None:
@@ -570,7 +597,7 @@ class Vector(BaseType):
         else:
             if opts:
                 # Ignore opts for now
-                descriptor_lookup(**opts)
+                desc = descriptor_lookup(**opts)  # noqa: F841 (keep desc in scope for context)
             rv = Vector._from_obj(ffi_new("GrB_Vector*"), self.dtype, self._size, name=name)
             call("GrB_Vector_dup", [_Pointer(rv), self])
         return rv
@@ -590,6 +617,7 @@ class Vector(BaseType):
         Returns
         -------
         :class:`~graphblas.Matrix`
+
         """
         from .matrix import Matrix
 
@@ -614,6 +642,7 @@ class Vector(BaseType):
         Use wait to force completion of the Vector.
 
         Has no effect in `blocking mode <../user_guide/init.html#graphblas-modes>`__.
+
         """
         how = how.lower()
         if how == "materialize":
@@ -638,6 +667,7 @@ class Vector(BaseType):
         Returns
         -------
         Python scalar
+
         """
         expr = self[index]
         if expr._is_scalar:
@@ -648,43 +678,6 @@ class Vector(BaseType):
             "A single index should be given, and the result will be a Python scalar."
         )
 
-    @classmethod
-    def from_values(cls, indices, values, dtype=None, *, size=None, dup_op=None, name=None):
-        """Create a new Vector from indices and values.
-
-        .. deprecated:: 2022.11.0
-            `Vector.from_values` will be removed in a future release.
-            Use `Vector.from_coo` instead. Will be removed in version 2023.9.0 or later
-
-        Parameters
-        ----------
-        indices : list or np.ndarray
-            Vector indices.
-        values : list or np.ndarray or scalar
-            List of values. If a scalar is provided, all values will be set to this single value.
-        dtype :
-            Data type of the Vector. If not provided, the values will be inspected
-            to choose an appropriate dtype.
-        size : int, optional
-            Size of the Vector. If not provided, ``size`` is computed from
-            the maximum index found in ``indices``.
-        dup_op : BinaryOp, optional
-            Function used to combine values if duplicate indices are found.
-            Leaving ``dup_op=None`` will raise an error if duplicates are found.
-        name : str, optional
-            Name to give the Vector.
-
-        Returns
-        -------
-        Vector
-        """
-        warnings.warn(
-            "`Vector.from_values(...)` is deprecated; please use `Vector.from_coo(...)` instead.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return cls.from_coo(indices, values, dtype, size=size, dup_op=dup_op, name=name)
-
     @classmethod
     def from_coo(cls, indices, values=1.0, dtype=None, *, size=None, dup_op=None, name=None):
         """Create a new Vector from indices and values.
@@ -717,6 +710,7 @@ class Vector(BaseType):
         Returns
         -------
         Vector
+
         """
         indices = ints_to_numpy_buffer(indices, np.uint64, name="indices")
         values, dtype = values_to_numpy_buffer(values, dtype, subarray_after=1)
@@ -774,6 +768,7 @@ class Vector(BaseType):
         Returns
         -------
         Vector
+
         """
         if isinstance(pairs, np.ndarray):
             raise TypeError("pairs as NumPy array is not supported; use `Vector.from_coo` instead")
@@ -825,6 +820,7 @@ class Vector(BaseType):
         Returns
         -------
         Vector
+
         """
         if type(value) is not Scalar:
             try:
@@ -877,6 +873,7 @@ class Vector(BaseType):
         Returns
         -------
         Vector
+
         """
         values, dtype = values_to_numpy_buffer(values, dtype, subarray_after=1)
         if values.ndim == 0:
@@ -925,6 +922,7 @@ class Vector(BaseType):
         Returns
         -------
         np.ndarray
+
         """
         if fill_value is None or self._nvals == self._size:
             if self._nvals != self._size:
@@ -995,16 +993,43 @@ class Vector(BaseType):
 
             # Functional syntax
             w << monoid.max(u | v)
+
         """
+        return self._ewise_add(other, op)
+
+    def _ewise_add(self, other, op=monoid.plus, is_infix=False):
         from .matrix import Matrix, MatrixExpression, TransposedMatrix
 
         method_name = "ewise_add"
-        other = self._expect_type(
-            other, (Vector, Matrix, TransposedMatrix), within=method_name, argname="other", op=op
-        )
-        op = get_typed_op(op, self.dtype, other.dtype, kind="binary")
-        # Per the spec, op may be a semiring, but this is weird, so don't.
-        self._expect_op(op, ("BinaryOp", "Monoid"), within=method_name, argname="op")
+        if is_infix:
+            from .infix import MatrixEwiseAddExpr, VectorEwiseAddExpr
+
+            other = self._expect_type(
+                other,
+                (Vector, Matrix, TransposedMatrix, MatrixEwiseAddExpr, VectorEwiseAddExpr),
+                within=method_name,
+                argname="other",
+                op=op,
+            )
+            op = _get_typed_op_from_exprs(op, self, other, kind="binary")
+            # Per the spec, op may be a semiring, but this is weird, so don't.
+            self._expect_op(op, ("BinaryOp", "Monoid"), within=method_name, argname="op")
+            if isinstance(self, VectorEwiseAddExpr):
+                self = op(self).new()
+            if isinstance(other, InfixExprBase):
+                other = op(other).new()
+        else:
+            other = self._expect_type(
+                other,
+                (Vector, Matrix, TransposedMatrix),
+                within=method_name,
+                argname="other",
+                op=op,
+            )
+            op = get_typed_op(op, self.dtype, other.dtype, kind="binary")
+            # Per the spec, op may be a semiring, but this is weird, so don't.
+            self._expect_op(op, ("BinaryOp", "Monoid"), within=method_name, argname="op")
+
         if other.ndim == 2:
             # Broadcast columnwise from the left
             if other._nrows != self._size:
@@ -1060,16 +1085,42 @@ class Vector(BaseType):
 
             # Functional syntax
             w << binary.gt(u & v)
+
         """
+        return self._ewise_mult(other, op)
+
+    def _ewise_mult(self, other, op=binary.times, is_infix=False):
         from .matrix import Matrix, MatrixExpression, TransposedMatrix
 
         method_name = "ewise_mult"
-        other = self._expect_type(
-            other, (Vector, Matrix, TransposedMatrix), within=method_name, argname="other", op=op
-        )
-        op = get_typed_op(op, self.dtype, other.dtype, kind="binary")
-        # Per the spec, op may be a semiring, but this is weird, so don't.
-        self._expect_op(op, ("BinaryOp", "Monoid"), within=method_name, argname="op")
+        if is_infix:
+            from .infix import MatrixEwiseMultExpr, VectorEwiseMultExpr
+
+            other = self._expect_type(
+                other,
+                (Vector, Matrix, TransposedMatrix, MatrixEwiseMultExpr, VectorEwiseMultExpr),
+                within=method_name,
+                argname="other",
+                op=op,
+            )
+            op = _get_typed_op_from_exprs(op, self, other, kind="binary")
+            # Per the spec, op may be a semiring, but this is weird, so don't.
+            self._expect_op(op, ("BinaryOp", "Monoid"), within=method_name, argname="op")
+            if isinstance(self, VectorEwiseMultExpr):
+                self = op(self).new()
+            if isinstance(other, InfixExprBase):
+                other = op(other).new()
+        else:
+            other = self._expect_type(
+                other,
+                (Vector, Matrix, TransposedMatrix),
+                within=method_name,
+                argname="other",
+                op=op,
+            )
+            op = get_typed_op(op, self.dtype, other.dtype, kind="binary")
+            # Per the spec, op may be a semiring, but this is weird, so don't.
+            self._expect_op(op, ("BinaryOp", "Monoid"), within=method_name, argname="op")
         if other.ndim == 2:
             # Broadcast columnwise from the left
             if other._nrows != self._size:
@@ -1128,14 +1179,37 @@ class Vector(BaseType):
 
             # Functional syntax
             w << binary.div(u | v, left_default=1, right_default=1)
+
         """
+        return self._ewise_union(other, op, left_default, right_default)
+
+    def _ewise_union(self, other, op, left_default, right_default, is_infix=False):
         from .matrix import Matrix, MatrixExpression, TransposedMatrix
 
         method_name = "ewise_union"
-        other = self._expect_type(
-            other, (Vector, Matrix, TransposedMatrix), within=method_name, argname="other", op=op
-        )
-        dtype = self.dtype if self.dtype._is_udt else None
+        if is_infix:
+            from .infix import MatrixEwiseAddExpr, VectorEwiseAddExpr
+
+            other = self._expect_type(
+                other,
+                (Vector, Matrix, TransposedMatrix, MatrixEwiseAddExpr, VectorEwiseAddExpr),
+                within=method_name,
+                argname="other",
+                op=op,
+            )
+            temp_op = _get_typed_op_from_exprs(op, self, other, kind="binary")
+        else:
+            other = self._expect_type(
+                other,
+                (Vector, Matrix, TransposedMatrix),
+                within=method_name,
+                argname="other",
+                op=op,
+            )
+            temp_op = get_typed_op(op, self.dtype, other.dtype, kind="binary")
+
+        left_dtype = temp_op.type
+        dtype = left_dtype if left_dtype._is_udt else None
         if type(left_default) is not Scalar:
             try:
                 left = Scalar.from_value(
@@ -1152,6 +1226,8 @@ class Vector(BaseType):
                 )
         else:
             left = _as_scalar(left_default, dtype, is_cscalar=False)  # pragma: is_grbscalar
+        right_dtype = temp_op.type2
+        dtype = right_dtype if right_dtype._is_udt else None
         if type(right_default) is not Scalar:
             try:
                 right = Scalar.from_value(
@@ -1168,12 +1244,29 @@ class Vector(BaseType):
                 )
         else:
             right = _as_scalar(right_default, dtype, is_cscalar=False)  # pragma: is_grbscalar
-        scalar_dtype = unify(left.dtype, right.dtype)
-        nonscalar_dtype = unify(self.dtype, other.dtype)
-        op = get_typed_op(op, scalar_dtype, nonscalar_dtype, is_left_scalar=True, kind="binary")
+
+        if is_infix:
+            op1 = _get_typed_op_from_exprs(op, self, right, kind="binary")
+            op2 = _get_typed_op_from_exprs(op, left, other, kind="binary")
+        else:
+            op1 = get_typed_op(op, self.dtype, right.dtype, kind="binary")
+            op2 = get_typed_op(op, left.dtype, other.dtype, kind="binary")
+        if op1 is not op2:
+            left_dtype = unify(op1.type, op2.type, is_right_scalar=True)
+            right_dtype = unify(op1.type2, op2.type2, is_left_scalar=True)
+            op = get_typed_op(op, left_dtype, right_dtype, kind="binary")
+        else:
+            op = op1
         self._expect_op(op, ("BinaryOp", "Monoid"), within=method_name, argname="op")
         if op.opclass == "Monoid":
             op = op.binaryop
+
+        if is_infix:
+            if isinstance(self, VectorEwiseAddExpr):
+                self = op(self, left_default=left, right_default=right).new()
+            if isinstance(other, InfixExprBase):
+                other = op(other, left_default=left, right_default=right).new()
+
         expr_repr = "{0.name}.{method_name}({2.name}, {op}, {1._expr_name}, {3._expr_name})"
         if other.ndim == 2:
             # Broadcast columnwise from the left
@@ -1201,11 +1294,10 @@ class Vector(BaseType):
                 expr_repr=expr_repr,
             )
         else:
-            dtype = unify(scalar_dtype, nonscalar_dtype, is_left_scalar=True)
             expr = VectorExpression(
                 method_name,
                 None,
-                [self, left, other, right, _v_union_v, (self, other, left, right, op, dtype)],
+                [self, left, other, right, _v_union_v, (self, other, left, right, op)],
                 expr_repr=expr_repr,
                 size=self._size,
                 op=op,
@@ -1242,15 +1334,37 @@ class Vector(BaseType):
 
             # Functional syntax
             C << semiring.min_plus(v @ A)
+
         """
+        return self._vxm(other, op)
+
+    def _vxm(self, other, op=semiring.plus_times, is_infix=False):
         from .matrix import Matrix, TransposedMatrix
 
         method_name = "vxm"
-        other = self._expect_type(
-            other, (Matrix, TransposedMatrix), within=method_name, argname="other", op=op
-        )
-        op = get_typed_op(op, self.dtype, other.dtype, kind="semiring")
-        self._expect_op(op, "Semiring", within=method_name, argname="op")
+        if is_infix:
+            from .infix import MatrixMatMulExpr, VectorMatMulExpr
+
+            other = self._expect_type(
+                other,
+                (Matrix, TransposedMatrix, MatrixMatMulExpr),
+                within=method_name,
+                argname="other",
+                op=op,
+            )
+            op = _get_typed_op_from_exprs(op, self, other, kind="semiring")
+            self._expect_op(op, "Semiring", within=method_name, argname="op")
+            if isinstance(self, VectorMatMulExpr):
+                self = op(self).new()
+            if isinstance(other, MatrixMatMulExpr):
+                other = op(other).new()
+        else:
+            other = self._expect_type(
+                other, (Matrix, TransposedMatrix), within=method_name, argname="other", op=op
+            )
+            op = get_typed_op(op, self.dtype, other.dtype, kind="semiring")
+            self._expect_op(op, "Semiring", within=method_name, argname="op")
+
         expr = VectorExpression(
             method_name,
             "GrB_vxm",
@@ -1300,6 +1414,7 @@ class Vector(BaseType):
 
             # Functional syntax
             w << op.abs(v)
+
         """
         method_name = "apply"
         extra_message = (
@@ -1445,6 +1560,7 @@ class Vector(BaseType):
 
             # Functional syntax
             w << select.value(v >= 1)
+
         """
         method_name = "select"
         if isinstance(op, str):
@@ -1500,6 +1616,7 @@ class Vector(BaseType):
             if thunk.dtype._is_udt:
                 dtype_name = "UDT"
                 thunk = _Pointer(thunk)
+                # NOT COVERED
             else:
                 dtype_name = thunk.dtype.name
             cfunc_name = f"GrB_Vector_select_{dtype_name}"
@@ -1538,6 +1655,7 @@ class Vector(BaseType):
         .. code-block:: python
 
             total << v.reduce(monoid.plus)
+
         """
         method_name = "reduce"
         op = get_typed_op(op, self.dtype, kind="binary|aggregator")
@@ -1590,11 +1708,29 @@ class Vector(BaseType):
         *Note*: This is not a standard GraphBLAS function, but fits with other functions in the
         `Matrix Multiplication <../user_guide/operations.html#matrix-multiply>`__
         family of functions.
+
         """
+        return self._inner(other, op)
+
+    def _inner(self, other, op=semiring.plus_times, is_infix=False):
         method_name = "inner"
-        other = self._expect_type(other, Vector, within=method_name, argname="other", op=op)
-        op = get_typed_op(op, self.dtype, other.dtype, kind="semiring")
-        self._expect_op(op, "Semiring", within=method_name, argname="op")
+        if is_infix:
+            from .infix import VectorMatMulExpr
+
+            other = self._expect_type(
+                other, (Vector, VectorMatMulExpr), within=method_name, argname="other", op=op
+            )
+            op = _get_typed_op_from_exprs(op, self, other, kind="semiring")
+            self._expect_op(op, "Semiring", within=method_name, argname="op")
+            if isinstance(self, VectorMatMulExpr):
+                self = op(self).new()
+            if isinstance(other, VectorMatMulExpr):
+                other = op(other).new()
+        else:
+            other = self._expect_type(other, Vector, within=method_name, argname="other", op=op)
+            op = get_typed_op(op, self.dtype, other.dtype, kind="semiring")
+            self._expect_op(op, "Semiring", within=method_name, argname="op")
+
         expr = ScalarExpression(
             method_name,
             "GrB_vxm",
@@ -1628,6 +1764,7 @@ class Vector(BaseType):
             C << v.outer(w, op=binary.times)
 
         *Note*: This is not a standard GraphBLAS function.
+
         """
         from .matrix import MatrixExpression
 
@@ -1676,6 +1813,7 @@ class Vector(BaseType):
         .. code-block:: python
 
             w = v.reposition(20).new()
+
         """
         if size is None:
             size = self._size
@@ -1714,7 +1852,7 @@ class Vector(BaseType):
             result = Scalar(dtype, is_cscalar=is_cscalar, name=name)
         if opts:
             # Ignore opts for now
-            descriptor_lookup(**opts)
+            desc = descriptor_lookup(**opts)  # noqa: F841 (keep desc in scope for context)
         if is_cscalar:
             dtype_name = "UDT" if dtype._is_udt else dtype.name
             if (
@@ -1817,13 +1955,14 @@ class Vector(BaseType):
                             shape = values.shape
                             try:
                                 vals = Vector.from_dense(values, dtype=dtype)
-                            except Exception:  # pragma: no cover (safety)
+                            except Exception:
                                 vals = None
                             else:
                                 if dtype.np_type.subdtype is not None:
                                     shape = vals.shape
                             if vals is None or shape != (size,):
                                 if dtype.np_type.subdtype is not None:
+                                    # NOT COVERED
                                     extra = (
                                         " (this is assigning to a vector with sub-array dtype "
                                         f"({dtype}), so array shape should include dtype shape)"
@@ -1935,6 +2074,7 @@ class Vector(BaseType):
         Returns
         -------
         Vector
+
         """
         indices = np.fromiter(d.keys(), np.uint64)
         if dtype is None:
@@ -1943,7 +2083,7 @@ class Vector(BaseType):
             # If we know the dtype, then using `np.fromiter` is much faster
             dtype = lookup_dtype(dtype)
             if dtype.np_type.subdtype is not None and np.__version__[:5] in {"1.21.", "1.22."}:
-                values, dtype = values_to_numpy_buffer(list(d.values()), dtype)
+                values, dtype = values_to_numpy_buffer(list(d.values()), dtype)  # FLAKY COVERAGE
             else:
                 values = np.fromiter(d.values(), dtype.np_type)
         if size is None and indices.size == 0:
@@ -1962,6 +2102,7 @@ class Vector(BaseType):
         Returns
         -------
         dict
+
         """
         indices, values = self.to_coo(sort=False)
         return dict(zip(indices.tolist(), values.tolist()))
@@ -2091,7 +2232,6 @@ class VectorExpression(BaseExpression):
     to_coo = wrapdoc(Vector.to_coo)(property(automethods.to_coo))
     to_dense = wrapdoc(Vector.to_dense)(property(automethods.to_dense))
     to_dict = wrapdoc(Vector.to_dict)(property(automethods.to_dict))
-    to_values = wrapdoc(Vector.to_values)(property(automethods.to_values))
     vxm = wrapdoc(Vector.vxm)(property(automethods.vxm))
     wait = wrapdoc(Vector.wait)(property(automethods.wait))
     # These raise exceptions
@@ -2133,6 +2273,9 @@ class VectorIndexExpr(AmbiguousAssignOrExtract):
         if clear:
             if dtype is None:
                 dtype = self.dtype
+            if opts:
+                # Ignore opts for now
+                desc = descriptor_lookup(**opts)  # noqa: F841 (keep desc in scope for context)
             return self.output_type(dtype, *self.shape, name=name)
         return self.new(dtype, mask=mask, name=name, **opts)
 
@@ -2176,7 +2319,6 @@ class VectorIndexExpr(AmbiguousAssignOrExtract):
     to_coo = wrapdoc(Vector.to_coo)(property(automethods.to_coo))
     to_dense = wrapdoc(Vector.to_dense)(property(automethods.to_dense))
     to_dict = wrapdoc(Vector.to_dict)(property(automethods.to_dict))
-    to_values = wrapdoc(Vector.to_values)(property(automethods.to_values))
     vxm = wrapdoc(Vector.vxm)(property(automethods.vxm))
     wait = wrapdoc(Vector.wait)(property(automethods.wait))
     # These raise exceptions
