@@ -8,7 +8,7 @@ _binary_to_select = {}
 
 
 def __dir__():
-    return globals().keys() | _delayed.keys()
+    return globals().keys() | _delayed.keys() | {"ss"}
 
 
 def __getattr__(key):
@@ -17,6 +17,18 @@ def __getattr__(key):
         rv = func(**kwargs)
         globals()[key] = rv
         return rv
+    if key == "ss":
+        from .. import backend
+
+        if backend != "suitesparse":
+            raise AttributeError(
+                f'module {__name__!r} only has attribute "ss" when backend is "suitesparse"'
+            )
+        from importlib import import_module
+
+        ss = import_module(".ss", __name__)
+        globals()["ss"] = ss
+        return ss
     raise AttributeError(f"module {__name__!r} has no attribute {key!r}")
 
 
@@ -57,9 +69,9 @@ def _resolve_expr(expr, callname, opname):
 
 
 def _match_expr(parent, expr):
-    """Match expressions to rewrite `A.select(A < 5)` into select expression.
+    """Match expressions to rewrite ``A.select(A < 5)`` into select expression.
 
-    The argument must match the parent, so this _won't_ be rewritten: `A.select(B < 5)`
+    The argument must match the parent, so this _won't_ be rewritten: ``A.select(B < 5)``
     """
     args = expr.args
     op = expr.op
@@ -76,56 +88,49 @@ def _match_expr(parent, expr):
 
 
 def value(expr):
-    """
-    An advanced select method which allows for easily expressing
-    value comparison logic.
+    """An advanced select method for easily expressing value comparison logic.
 
     Example usage:
     >>> gb.select.value(A > 0)
 
-    The example will dispatch to `gb.select.valuegt(A, 0)`
+    The example will dispatch to ``gb.select.valuegt(A, 0)``
     while being nicer to read.
     """
     return _resolve_expr(expr, "value", "value")
 
 
 def row(expr):
-    """
-    An advanced select method which allows for easily expressing
-    Matrix row index comparison logic.
+    """An advanced select method for easily expressing Matrix row index comparison logic.
 
     Example usage:
     >>> gb.select.row(A <= 5)
 
-    The example will dispatch to `gb.select.rowle(A, 5)`
+    The example will dispatch to ``gb.select.rowle(A, 5)``
     while being potentially nicer to read.
     """
     return _resolve_expr(expr, "row", "row")
 
 
 def column(expr):
-    """
-    An advanced select method which allows for easily expressing
-    Matrix column index comparison logic.
+    """An advanced select method for easily expressing Matrix column index comparison logic.
 
     Example usage:
     >>> gb.select.column(A <= 5)
 
-    The example will dispatch to `gb.select.colle(A, 5)`
+    The example will dispatch to ``gb.select.colle(A, 5)``
     while being potentially nicer to read.
     """
     return _resolve_expr(expr, "column", "col")
 
 
 def index(expr):
-    """
-    An advanced select method which allows for easily expressing
+    """An advanced select method which allows for easily expressing
     Vector index comparison logic.
 
     Example usage:
     >>> gb.select.index(v <= 5)
 
-    The example will dispatch to `gb.select.indexle(v, 5)`
+    The example will dispatch to ``gb.select.indexle(v, 5)``
     while being potentially nicer to read.
     """
     return _resolve_expr(expr, "index", "index")
